@@ -17,22 +17,14 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.4.9 (database v19.9)',
-	'GNUmed 1.4.9 Release Notes:
+	'Release Notes for GNUmed 1.4.12 (database v19.12)',
+	'GNUmed 1.4.12 Release Notes:
 
-	1.4.9
+	1.4.12
 
-FIX: bug in current_meds placeholder
-FIX: utterly slow praxis branch PRW [thanks Jim]
-FIX: bug with changing praxis definition
-
-	19.9 -- Requires PostgreSQL 9.1 !
-
-IMPROVED: add some indices to dem.org(_unit)
-IMPROVED: faster view for praxis branches
-IMPROVED: add pg_trgm extension
-IMPROVED: speed of dem.v_org_units
+FIX: failing deletion of bills [thanks Marc]
 
+	19.12 -- Requires PostgreSQL 9.1 !
 ');
 
 -- --------------------------------------------------------------
